#include "reference.h"
#define NUM_OUT 6
#define NUM_SONG 6 //Current number of songs

int readings[6];
int musclePin[6] = {A0, A1, A2, A3, A4, A5};
int maxINPUT = 800;

int button1 = 0; //Red Button in the board. Used to shuffle through different songs
int button2 = 0; //White button in the board. Used to increase the pitch of the notes

int notesMHLL[] =            {NOTE_E4, NOTE_D4, NOTE_C4, NOTE_G4, 0,       0};       //musical notes for Mary had a Little Lamb
int notesFJ[] =              {NOTE_G4, NOTE_A4, NOTE_B4, NOTE_C5, NOTE_D5, NOTE_E5}; //musical notes for Frère Jacques
int notesMajorPentatonic[] = {NOTE_C5, NOTE_D5, NOTE_E5, NOTE_G5, NOTE_A5, 0};       //musical notes for a pentatonic scale
int notesMinorBlues[] =      {NOTE_C3, NOTE_DS3, NOTE_F3, NOTE_FS3, NOTE_G3, NOTE_AS3};    //musical notes for a minor blues scale
int notesRayBass[] =         {NOTE_E1, NOTE_A1, NOTE_B1, 0, 0, 0};       //notes for the first part of the bass in Ray Charles' "What'd I say"
int notesImperialMarch[] =   {NOTE_G4, NOTE_E4, NOTE_B4, NOTE_D5, NOTE_E5, NOTE_FS4}; // notes for the Imperial March

float distort = 2;

void setup() {
  Serial.begin(9600);
  for (int i = 0; i < NUM_OUT; i++) {
    pinMode(8, OUTPUT);
  }
  digitalWrite(13, HIGH); //Turns all the LEDs in the lower part of the board (under the quarter-inch jacks)
}

void loop() {

  int biggestVal = 0;
  int index = 0;

  int song[6]; //array set to be equal to one of the other note arrays (MHLL, FJ, Pentatonic). Song can be swtiched using the red button

  if (digitalRead(5) == HIGH) {
    delay(200);
    button1++;
  }

  switch (button1 % NUM_SONG) { //checks what set of notes to use
    case 0:
      Serial.print("//MHLL// ");
      for (int i = 0; i < NUM_OUT; i++) {
        song[i] = notesMHLL[i];
        distort = 2;
      }
      break;
    case 1:
      Serial.print("//FJ// ");
      for (int i = 0; i < NUM_OUT; i++) {
        song[i] = notesFJ[i];
        distort = 2;
      }
      break;
    case 2:
      Serial.print("//PENT.// ");
      for (int i = 0; i < NUM_OUT; i++) {
        song[i] = notesMajorPentatonic[i];
        distort = 2;
      }
      break;
    case 3:
      Serial.print("//BLUE// ");
      for (int i = 0; i < NUM_OUT; i++) {
        song[i] = notesMinorBlues[i];
        distort = 2;
      }
      break;
    case 4:
      Serial.print("//RAY//");
      for(int i = 0; i < NUM_OUT; i++){
        song[i] = notesRayBass[i];
        distort = 1.3348;
      }
      break;
    case 5:
      Serial.print("//DUNDUNDUN//");
      for(int i = 0; i < NUM_OUT; i++){
        song[i] = notesImperialMarch[i];
        distort = 0.5;
      }
      break;
  }

  button2 = digitalRead(6);
  if (button2 == HIGH) {
    //checks if button2 is clicked. If it is, increases the frequency of all the notes

    Serial.print("***HIGHPITCH*** ");
    for (int i = 0; i < NUM_OUT; i++) {
      song[i] = distort * song[i];
    }
  }

  for (int i = 0; i < NUM_OUT; i++) {
    //First finds the value for a specific channel and outputs that raw value to the monitor. Then chacks is that value is the largest so far.

    readings[i] = analogRead(musclePin[i]);

    Serial.print("Channel ");
    Serial.print(readings[i]);
    Serial.print(" ");

    readings[i] = constrain(readings[i], 0, maxINPUT);
    readings[i] = map(readings[i], 0, maxINPUT, 0, 200);

    if (biggestVal < readings[i]) {
      biggestVal = readings[i];
      index = i;
    }
  }

  Serial.println();

  if (biggestVal > 30) {
    //Checks if the largest reading is bigger than the threshold
    tone(8, song[index], biggestVal);

  }
  else {
    //Otherwise plays no sound. This helps eliminate noise from small fluctuations
    tone(8, 0, 10);
  }
}
